@@ -1,7 +1,7 @@
 import numpy as np
 from ..encoded_array import BaseEncoding, Encoding, NumericEncoding
 from .alphabet_encoding import (AlphabetEncoding, DNAEncoding, RNAENcoding,
-                                AminoAcidEncoding,
+                                AminoAcidEncoding, ACGTnEncoding,
                                 CigarOpEncoding, BamEncoding, StrandEncoding)
 
 
@@ -56,4 +56,4 @@ def set_backend(lib):
     alphabet_encoding.np = lib
 
     from . import kmer_encodings
-    kmer_encodings.np = lib
\ No newline at end of file
+    kmer_encodings.np = lib
