@@ -28,10 +28,10 @@ class AlphabetEncoding(OneToOneEncoding):
         ret = self._lookup[byte_array]
         if np.any(ret == 255):
             offset = np.flatnonzero(ret.ravel()==255)[0]
-            tmp = [chr(c) for c in byte_array.ravel()[ret.ravel()==255]]
+            tmp = [chr(c) for c in byte_array.ravel()[ret.ravel()==255]][:10]
             raise EncodingError(f"Error when encoding {''.join(chr(c) for c in byte_array.ravel()[0:100])} "
                                 f"to {self.__class__.__name__}. Invalid character(s): "
-                                f"{tmp}", offset)
+                                f"{tmp}{[ord(c) for c in tmp]}", offset)
         return ret
 
     def _decode(self, encoded):
@@ -78,7 +78,14 @@ RNAENcoding = ACUGEncoding
 AminoAcidEncoding = AlphabetEncoding('ACDEFGHIKLMNPQRSTVWY')
 BamEncoding = AlphabetEncoding("=ACMGRSVTWYHKDBN")
 CigarOpEncoding = AlphabetEncoding("MIDNSHP=X")
-StrandEncoding = AlphabetEncoding("+-.")
+
+
+class FlatAlphabetEncoding(AlphabetEncoding):
+    def _encode(self, *args, **kwargs):
+        return super()._encode(*args, **kwargs).ravel()
+
+
+StrandEncoding = FlatAlphabetEncoding("+-.")
 
 
 def get_alphabet_encodings():
