@@ -3,5 +3,5 @@ from .indexed_files import open_indexed
 from .multiline_buffer import MultiLineFastaBuffer
 from .file_buffers import (TwoLineFastaBuffer, FastQBuffer)
 from .delimited_buffers import (BedBuffer, Bed6Buffer, VCFBuffer, PhasedVCFMatrixBuffer, VCFMatrixBuffer,
-                                GfaSequenceBuffer, get_bufferclass_for_datatype)
+                                GfaSequenceBuffer, get_bufferclass_for_datatype, NarrowPeakBuffer)
 from .indexed_fasta import IndexedFasta
