@@ -130,9 +130,11 @@ class NumpyFileReader:
                 self._file_obj.seek(buff.size - chunk.size, 1)
             else:
                 self._prepend = chunk[buff.size:]
+
         if chunk is not None and chunk.size:
             self.n_bytes_read += buff.size
             self.n_lines_read += buff.n_lines
+            #buff.set_context("context", "test")
             return wrapper(buff)
 
     def read_chunks(self, min_chunk_size: int = 5000000, max_chunk_size: int = None):
@@ -192,6 +194,7 @@ class NpBufferedWriter:
             if hasattr(self._file_obj, "name")
             else str(self._file_obj)
         )
+        self._header_written = False
 
     def __enter__(self):
         return self
@@ -212,10 +215,6 @@ class NpBufferedWriter:
             dataset containing entries
 
         """
-        if hasattr(self._buffer_type, 'make_header') and (not hasattr(self._file_obj, "mode") or self._file_obj.mode != 'ab') and getattr(self._buffer_type, 'INCLUDE_HEADER', False):
-            header_array = self._buffer_type.make_header(data)
-            self._file_obj.write(header_array)
-
         if isinstance(data, BnpStream):
             for buf in data:
                 if len(buf) > 0:
@@ -226,6 +225,14 @@ class NpBufferedWriter:
                 if len(buf) > 0:
                     self.write(buf)
             return
+
+        if hasattr(self._buffer_type, 'make_header') and \
+                (not hasattr(self._file_obj, "mode") or self._file_obj.mode != 'ab'): # and \
+                #getattr(self._buffer_type, 'HAS_UNCOMMENTED_HEADER_LINE', False):
+            header_array = self._buffer_type.make_header(data)
+            self._file_obj.write(header_array)
+
+
         bytes_array = self._buffer_type.from_data(data)
         if isinstance(bytes_array, EncodedArray):
             bytes_array = bytes_array.raw()
