@@ -1,5 +1,5 @@
 import numpy as np
-
+from typing import List, Union
 from npstructures import RaggedArray, RaggedShape
 from npstructures.util import unsafe_extend_right, unsafe_extend_left
 from npstructures.raggedarray.raggedslice import ragged_slice
@@ -144,7 +144,7 @@ def str_to_float(number_text: EncodedRaggedArray) -> np.ndarray:
     """
     number_text = as_encoded_array(number_text)
     assert number_text.encoding == BaseEncoding
-    return np.array([float(row.to_string()) for row in number_text])
+    # return np.array([float(row.to_string()) for row in number_text])
 
     scientific = np.any(number_text == "e", axis=-1)
     numbers = np.empty(len(number_text))
@@ -276,7 +276,7 @@ def join(sequences: EncodedRaggedArray, sep: str = "\t", keep_last: bool = False
     return new_array.ravel()[:-1]
 
 
-def split(sequence: EncodedArray, sep: str = ",") -> EncodedRaggedArray:
+def split(sequence: EncodedArray, sep: Union[str, List[str]] = ",") -> EncodedRaggedArray:
     """Split the sequence on `sep` character into a ragged array
 
     Parameters
@@ -295,7 +295,12 @@ def split(sequence: EncodedArray, sep: str = ",") -> EncodedRaggedArray:
     --------
     """
     us = unsafe_extend_right(sequence)
-    mask = us == sep
+    if isinstance(sep, list):
+        mask = (us == sep[0])
+        for s in sep[1:]:
+            mask |= (us == s)
+    else:
+        mask = us == sep
     mask[-1] = True
     sep_idx = np.flatnonzero(mask)
     lens = np.diff(unsafe_extend_left(sep_idx))
