@@ -1,6 +1,8 @@
+from numpy.testing import assert_equal
 from bionumpy.io.indexed_fasta import create_index
 from bionumpy.datatypes import Interval
 from bionumpy.util.testing import assert_encoded_array_equal
+from bionumpy.encodings.string_encodings import StringEncoding
 import bionumpy as bnp
 import numpy as np
 
@@ -15,6 +17,7 @@ import numpy as np
 
 def test_fasta_index():
     index = create_index("example_data/small_genome.fa")
+    assert_equal(index.length, [300, 600, 900, 1200])
 
 
 def test_dictlike():
@@ -31,14 +34,13 @@ def test_dictlike():
 
 def test_get_sequences():
     idx_fasta = bnp.open_indexed("example_data/small_genome.fa")
-    intervals = Interval.from_entry_tuples([("1", 10, 20),
+    _intervals = Interval.from_entry_tuples([("1", 10, 20),
                                             ("2", 11, 50),
                                             ("1", 5, 10),
-                                            ("3", 10, 110)])
+                                             ("3", 10, 110),
+                                             ("1", 80, 250)])
+    intervals = bnp.bnpdataclass.replace(_intervals, chromosome=bnp.as_encoded_array(_intervals.chromosome, StringEncoding(['0', '1', '2', '3'])))
     sequences = idx_fasta.get_interval_sequences(intervals)
-    assert np.all(sequences.lengths == [10, 39, 5, 100])
+    assert np.all(sequences.lengths == [10, 39, 5, 100, 170])
     for interval, sequence in zip(intervals, sequences):
-        print(interval)
-        assert_encoded_array_equal(sequence, idx_fasta[interval.chromosome.to_string()][int(interval.start):int(interval.stop)])
-
-
+        assert sequence.to_string() == idx_fasta[interval.chromosome.to_string()][int(interval.start):int(interval.stop)].to_string()
